Coverage for scipy\_distributor_init.py: 100%

# Coverage for scipy\_distributor_init.py : 100%

## 0 statements 0 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 | """ Distributor init file Distributors: you can add custom code here to support particular distributions of scipy. For example, this is a good place to put any checks for hardware requirements. The scipy standard source distribution will not put code in this file, so you can safely replace this file with your own version. """